==> symfony_6.4.21+dfsg.orig.tar.xz: symfony-6.4.21/src/Symfony/Component/Intl/Resources/data/timezones/oc.php <==
<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'ora al meridian de Greenwich (Abidjan)',
        'Africa/Accra' => 'ora al meridian de Greenwich (Accra)',
        'Africa/Bamako' => 'ora al meridian de Greenwich (Bamako)',
        'Africa/Banjul' => 'ora al meridian de Greenwich (Banjul)',
        'Africa/Bissau' => 'ora al meridian de Greenwich (Bissau)',
        'Africa/Ceuta' => 'ora de Espanha (Ceuta)',
        'Africa/Conakry' => 'ora al meridian de Greenwich (Conakry)',
        'Africa/Dakar' => 'ora al meridian de Greenwich (Dakar)',
        'Africa/Freetown' => 'ora al meridian de Greenwich (Freetown)',
        'Africa/Lome' => 'ora al meridian de Greenwich (Lome)',
        'Africa/Monrovia' => 'ora al meridian de Greenwich (Monrovia)',
        'Africa/Nouakchott' => 'ora al meridian de Greenwich (Nouakchott)',
        'Africa/Ouagadougou' => 'ora al meridian de Greenwich (Ouagadougou)',
        'Africa/Sao_Tome' => 'ora al meridian de Greenwich (São Tomé)',
        'America/Danmarkshavn' => 'ora al meridian de Greenwich (Danmarkshavn)',
        'Antarctica/Troll' => 'ora al meridian de Greenwich (Troll)',
        'Asia/Hong_Kong' => 'ora de Hong Kong (Hong Kong)',
        'Atlantic/Canary' => 'ora de Espanha (Canary)',
        'Atlantic/Reykjavik' => 'ora al meridian de Greenwich (Reykjavik)',
        'Atlantic/St_Helena' => 'ora al meridian de Greenwich (St. Helena)',
        'Etc/GMT' => 'ora al meridian de Greenwich',
        'Europe/Dublin' => 'ora al meridian de Greenwich (Dublin)',
        'Europe/Guernsey' => 'ora al meridian de Greenwich (Guernsey)',
        'Europe/Isle_of_Man' => 'ora al meridian de Greenwich (Isle of Man)',
        'Europe/Jersey' => 'ora al meridian de Greenwich (Jersey)',
        'Europe/London' => 'ora al meridian de Greenwich (London)',
        'Europe/Madrid' => 'ora de Espanha (Madrid)',
        'Europe/Paris' => 'ora de França (Paris)',
    ],
    'Meta' => [
        'GmtFormat' => 'UTC%s',
    ],
];

==> symfony_8.0.2+dfsg.orig.tar.xz: symfony-8.0.2/src/Symfony/Component/Intl/Resources/data/timezones/oc.php <==
<?php

return [
    'Names' => [
        'Africa/Abidjan' => 'ora al meridian de Greenwich (Abidjan)',
        'Africa/Accra' => 'ora al meridian de Greenwich (Accra)',
        'Africa/Bamako' => 'ora al meridian de Greenwich (Bamako)',
        'Africa/Banjul' => 'ora al meridian de Greenwich (Banjul)',
        'Africa/Bissau' => 'ora al meridian de Greenwich (Bissau)',
        'Africa/Ceuta' => 'ora de Espanha (Ceuta)',
        'Africa/Conakry' => 'ora al meridian de Greenwich (Conakry)',
        'Africa/Dakar' => 'ora al meridian de Greenwich (Dakar)',
        'Africa/Freetown' => 'ora al meridian de Greenwich (Freetown)',
        'Africa/Lome' => 'ora al meridian de Greenwich (Lomé)',
        'Africa/Monrovia' => 'ora al meridian de Greenwich (Monrovia)',
        'Africa/Nouakchott' => 'ora al meridian de Greenwich (Nouakchott)',
        'Africa/Ouagadougou' => 'ora al meridian de Greenwich (Ouagadougou)',
        'Africa/Sao_Tome' => 'ora al meridian de Greenwich (São Tomé)',
        'America/Danmarkshavn' => 'ora al meridian de Greenwich (Danmarkshavn)',
        'Antarctica/Troll' => 'ora al meridian de Greenwich (Troll)',
        'Asia/Hong_Kong' => 'ora de Hong Kong (Hong Kong)',
        'Atlantic/Canary' => 'ora de Espanha (Canarias)',
        'Atlantic/Reykjavik' => 'ora al meridian de Greenwich (Reykjavik)',
        'Atlantic/St_Helena' => 'ora al meridian de Greenwich (St. Helena)',
        'Etc/GMT' => 'ora al meridian de Greenwich',
        'Europe/Guernsey' => 'ora al meridian de Greenwich (Guernsey)',
        'Europe/Isle_of_Man' => 'ora al meridian de Greenwich (Isle of Man)',
        'Europe/Jersey' => 'ora al meridian de Greenwich (Jersey)',
        'Europe/London' => 'ora al meridian de Greenwich (London)',
        'Europe/Madrid' => 'ora de Espanha (Madrid)',
        'Europe/Paris' => 'ora de França (Paris)',
    ],
    'Meta' => [
        'GmtFormat' => 'UTC%s',
    ],
];
